import QtQuick 1.1
import com.nokia.meego 1.0

import "file:///usr/lib/qt4/imports/com/nokia/meego/UIConstants.js" as UI

import "config.js" as Conf

Page {
	id: stopPage

	property int stopId
	property string title

	Component {
		id: routeDelegate

		Item {
			height: Math.max(UI.LIST_ITEM_HEIGHT_DEFAULT, textDirection.height)
					 + UI.PADDING_MEDIUM
			width: parent.width

			Text {
				id: textTitle
				text: title
				font.pixelSize: UI.FONT_LARGE
				color: UI.COLOR_INVERTED_FOREGROUND
			}
			Text {
				id: textDirection
				text: directionTitle? "на " + directionTitle : ""
				wrapMode: Text.WordWrap
				anchors {
					left: textTitle.right
					leftMargin: UI.DEFAULT_MARGIN*2
					right: textZa.left
					rightMargin: UI.DEFAULT_MARGIN
				}
				font.pixelSize: UI.FONT_DEFAULT
				color: UI.COLOR_INVERTED_SECONDARY_FOREGROUND
			}

			Text {
				id: textZa
				text: "за "
				visible: typeof(timeLeft) !== "undefined"
							&& timeLeft.indexOf("-") === -1
				anchors {
					right: textMinutes.left
					bottom: textDirection.bottom
				}
				font.pixelSize: UI.FONT_DEFAULT
				color: UI.COLOR_INVERTED_SECONDARY_FOREGROUND
			}
			Text {
				id: textMinutes
				text: typeof(timeLeft) === "undefined"? "" : timeLeft
				anchors {
					right: textHv.left
					bottom: textDirection.bottom
				}

				font.pixelSize: UI.FONT_XLARGE
				color: "orange"
			}
			Text {
				id: textHv
				text: "хв"
				visible: typeof(timeLeft) !== "undefined"
				anchors.right: parent.right
				anchors.top: textMinutes.top
				font.pixelSize: UI.FONT_DEFAULT
				color: "orange"
			}
		}
	}

	Component {
		id: sectionDelegate
		Text {
			text: section
			verticalAlignment: Text.AlignVCenter
			font.pixelSize: UI.FONT_LARGE
			height: UI.LIST_ITEM_HEIGHT_DEFAULT + UI.PADDING_MEDIUM
			color: UI.COLOR_INVERTED_FOREGROUND
		}
	}
	
	ListView {
		id: routeListView
		anchors.fill: parent

		RouteListModel {
			id: routeListModel
			stopId: stopPage.stopId
		}

		model: routeListModel.model
		delegate: routeDelegate	

		header: ListHeader { heading: title }
		
		section.property: "transportName"
		// Seems labelPositioning appears in Qt5
		//section.labelPositioning: ViewSection.CurrentLabelAtStart
		section.delegate: sectionDelegate
	}

	Timer {
		id: timer
		interval: Conf.updateArrivalInterval; repeat: true
		running: Qt.application.active
		onTriggered: routeListModel.updateRoutes()
	}

    Connections {
        target: Qt.application
        onActiveChanged: 
			if(Qt.application.active) {
				routeListModel.updateRoutes(); 
				timer.restart()
			}
	}

	tools: ToolBarLayout {
		ToolIcon {
			iconId: "toolbar-back"

			onClicked: {
				pageStack.pop()
			}
		}
	}
}
