import QtQuick 1.1
import com.nokia.meego 1.0
import QtMobility.location 1.2

import "file:///usr/lib/qt4/imports/com/nokia/meego/UIConstants.js" as UI

import "config.js" as Conf

Page {
	id: stopsAroundPage

	Component.onCompleted: theme.inverted = true

	property Coordinate curCoord: positionSource.position.coordinate
	Coordinate { 
		id: prevCoord
		latitude: 0
	}

	// Stop retrieving position information when component is to be destroyed
    Component.onDestruction: positionSource.stop()

	// Stop position updates if the app is inactive
    Connections {
        target: Qt.application
        onActiveChanged: {
            if (Qt.application.active)
                positionSource.start()
            else
                positionSource.stop()
        }
    }
    // Stop position updates if the page is inactive
	onStatusChanged: {
		if(status == PageStatus.Activating)
			positionSource.start()
		else if(status == PageStatus.Deactivating)
			positionSource.stop()
	}

	// Source for retrieving the positioning information
    PositionSource {
        id: positionSource

        updateInterval: Conf.updatePositionInterval
        active: true

        onPositionChanged: updateGeoInfo()
    }

    function updateGeoInfo() {
		if(!prevCoord.latitude
			|| curCoord.distanceTo(prevCoord) > Conf.movedDistance )
		{
			stopListModel.moved()
			prevCoord.latitude = curCoord.latitude
			prevCoord.longitude = curCoord.longitude
		}
    }

	Component {
		id: stopItemDelegate

		Item {
			height: Math.max(UI.LIST_ITEM_HEIGHT_DEFAULT, text.height)
					 + UI.PADDING_MEDIUM
			width: parent.width

			RouteListModel {
				id: routeListModel
				stopId: id

				function isEmpty(o) 
				{
					for(var p in o) return false
					return true
				}

				function allRoutesStr()
				{
					if(model.count < 1)
						return ""
					
					var add_route = (function() {
						var cur_trans_key = "", numbers_added
						return function(r) {
							var s = ""
							if(r.transportKey != cur_trans_key) {
								if(cur_trans_key != "") // if not the first one
									s += ", "
								cur_trans_key = r.transportKey
								numbers_added = {}	
								if(typeof Conf.transportAbbrev[cur_trans_key]
										!= "undefined")
									s+= Conf.transportAbbrev[cur_trans_key] +" "
							}
							if(!numbers_added[r.title]) {
								if(!isEmpty(numbers_added)) // not the first one
									s += " "
								s += r.title
								numbers_added[r.title] = true
							}
							return s
						}
					})()

					var str = add_route(model.get(0))
					for(var i=1; i < model.count; i++)
						str += add_route(model.get(i))						

					return str
				}

				function allDirectionsStr()
				{
					if(model.count < 1)
						return ""

					var add_dir = (function() {
						var dirs_added = {}
						return function(r) {
							var s = ""
							if(!dirs_added[r.directionTitle]) {
								if(!isEmpty(dirs_added))
									s += ", "
								s += r.directionTitle
								dirs_added[r.directionTitle] = true
							}
							return s
						}
					})()

					var str = add_dir(model.get(0))
					for(var i=1; i < model.count; i++)
						str += add_dir(model.get(i))						

					return str
				}
			}
	
			BorderImage {
				id: highlight
				anchors.fill: parent
				visible: mouseArea.pressed
				source: "image://theme/meegotouch-list-inverted-background-pressed-center"
			}
			Item {
				id: text
				height:	textTitle.height + textRoutes.height
						+ textDirections.height
				anchors.verticalCenter: parent.verticalCenter
				Text {
					id: textTitle
					text: title
					anchors.top: parent.top
					elide: Text.ElideRight
					font.pixelSize: UI.FONT_LARGE
					color: UI.COLOR_INVERTED_FOREGROUND
				}
				Text {
					id: textRoutes
					text: routeListModel.allRoutesStr()
					width: highlight.width
					anchors.top: textTitle.bottom
					wrapMode: Text.WordWrap
					maximumLineCount: 1
					elide: Text.ElideRight
					font.pixelSize: UI.FONT_DEFAULT
					color: UI.COLOR_SECONDARY_FOREGROUND
				}
				Text {
					id: textDirections
					text: "У бік " + routeListModel.allDirectionsStr()
					width: highlight.width
					anchors.top: textRoutes.bottom
					wrapMode: Text.WordWrap
					maximumLineCount: 2
					elide: Text.ElideRight
					font.pixelSize: UI.FONT_DEFAULT
					color: UI.COLOR_SECONDARY_FOREGROUND
				}
			}
			MouseArea {
				id: mouseArea
				anchors.fill: highlight
				onClicked: {
					pageStack.push(Qt.resolvedUrl("StopPage.qml"),
									{stopId: model.id, title: model.title})
				}
			}
		}
	}
	
	ListView {
        id: stopListView
		anchors.fill: parent

		StopListModel {
			id: stopListModel
			location: curCoord
		}

		model: stopListModel.model
		delegate: stopItemDelegate
		
		header: ListHeader { heading: "Зупинки навколо" }
	}

	ScrollDecorator {
		flickableItem: stopListView
	}
}
